Skip to contents

Extract contrast names from the SEStats object's sedesign.

Usage

## S7 method for class <SEStats>
contrast_names(object)

Arguments

x

An SEStats object

Value

Character vector of contrast names

Details

This is a read-only accessor that retrieves the contrast names from the SEDesign object stored in the SEStats object. Values cannot be modified through this accessor, as the design is fixed when results are created.

Examples

if (FALSE) {
  contrast_names(sestats_object)
}