Extract factor names from the SEStats object's sedesign.
Usage
## S7 method for class <SEStats>
factors(object)Details
This is a read-only accessor that retrieves the factor names from the SEDesign object stored in the SEStats object. Values cannot be modified through this accessor, as the design is fixed when results are created.
See also
Other SEStats objects:
SEStats(),
contrast_names,SEStats-method,
groups,SEStats-method,
print,SEStats-method,
samples,SEStats-method
Examples
if (FALSE) {
factors(sestats_object)
}