Skip to contents

Convert NanoStringGeoMxSet to SummarizedExperiment, combining sData and phenoData into colData

Usage

geomx_to_se(x, assay_names = NULL, verbose = FALSE, ...)

Arguments

x

NanoStringGeoMxSet object

assay_names

character vector with one or more assay names. The default NULL will use all available assay names recognized by se_to_assay_names().

...

additional arguments are ignored.

Value

SummarizedExperiment with rowData, colData, and assays.

Details

The main purpose of this function is to convert GeomxTools::NanoStringGeoMxSet-class to SummarizedExperiment while also handling the oddity that the GeoMx data stores some sample (column) annotation in slot sData and others in slot phenoData. These two tables are combined into one colData entry in the output object.

Each data matrix in assayData from GeoMx is stored into the corresponding assays entry in the output object.