Skip to contents

groups() returns the design group names, equivalent to colnames(design(object)). groups()<- renames design groups, updating colnames(design) and rownames(contrasts) together.

Usage

groups(object, ...)

groups(object, ...) <- value

Arguments

object

SEDesign object

...

additional arguments are ignored

value

character vector, length equal to ncol(design(object))

Details

In principle, design groups are derived identifiers and should not need to be renamed directly (prefer re-running groups_to_sedesign() with updated inputs). groups()<- is provided for convenience, but use it with care: design_df (and therefore factors() labels derived from group names) is rebuilt from the new group names, which resets any customized factors()<- labels if the number of underlying factors changes.