Skip to contents

List to value incidence matrix, intended as an internal function

Usage

list2im_value_internal(
  setlist,
  empty = NULL,
  do_sparse = FALSE,
  force_sign = FALSE,
  ...
)

Arguments

setlist

list of vectors

empty

default 0, single value used for missing entries.

do_sparse

logical indicating whether to convert output to sparse matrix, not currently implemented.

force_sign

logical default FALSE, using TRUE will convert numeric to integer sign using sign().

...

additional arguments are ignored.