Skip to contents

S7 objects bypass the classic S4 show generic for console auto-printing; a plain S3 print.SEDesign method is used instead, since S7 objects retain "SEDesign" in their S3 class() vector.

Usage

## S7 method for class <SEDesign>
print(x, ...)

Arguments

x

SEDesign object

...

additional arguments are ignored

Value

This function is called for its output to console. It invisibly returns the input object.

Details

The summary includes:

  • the number of samples, groups, and contrasts

  • Each factor name, with factor levels.

Factor levels are printed in order, so that the first entry is prioritized as the control in subsequent contrasts.

For example: 'level1', 'level2', 'level3' should always produce contrasts 'level2-level1', 'level3-level1', 'level3-level2'. It should not produce a contrast 'level2-level3'.