SEDesign enforces the relationship between individual samples,
design groups, and groups involved in statistical contrasts.
Arguments
- design
matrixwith rownames as samples, colnames as design groups, containing 0/1 sample-to-group association values.- contrasts
matrixwith rownames matchingcolnames(design), and colnames as contrast names, containing contrast coefficients.- samples
charactervector of sample identifiers, typically equal torownames(design).- factors
charactervector of labels for the underlying experimental factors, equivalent tocolnames(design_df), i.e. the columns produced by splitting each design group name (groups(object)) on"_". When empty, or when its length does not match the number of underlying factors, it is auto-populated with"factor1","factor2", etc. Editingfactors()only renames these labels (used primarily byprint()); it has no effect ondesign,contrasts, orgroups().
Details
In addition to the four constructor arguments below, SEDesign objects
carry two internal-use properties, accessible via @:
design_df:data.framewith one row per design group (groups(object), i.e.colnames(design)), derived by splitting each group name on"_"into one column per underlying experimental factor. Column names default to"factor1","factor2", etc., and can be customized viafactors()<-.contrasts_df:data.frame, cached result ofcontrasts_to_factors(), refreshed wheneverdesignorcontrastsare updated.
See also
Other jam experiment design:
[,SEDesign-method,
check_sedesign(),
contrast2comp(),
contrast_colors_by_group(),
contrast_names_to_sedesign(),
contrastnames(),
contrasts(),
contrasts<-(),
contrasts_to_factors(),
contrasts_to_venn_setlists(),
design,SEDesign-method,
draw_oneway_contrast(),
draw_twoway_contrast(),
factors(),
filter_contrast_names(),
groups(),
groups_to_sedesign(),
plot.SEDesign(),
plot_sedesign(),
print,SEDesign-method,
samples(),
sedesign_to_factors(),
sort_contrasts(),
validate_sedesign()