Convert NanoStringGeoMxSet to SummarizedExperiment, combining sData and phenoData into colData
Arguments
- x
NanoStringGeoMxSetobject- assay_names
charactervector with one or more assay names. The default NULL will use all available assay names recognized byse_to_assay_names().- ...
additional arguments are ignored.
Details
The main purpose of this function is to convert
GeomxTools::NanoStringGeoMxSet-class to SummarizedExperiment
while also handling the oddity that the GeoMx data stores
some sample (column) annotation in slot sData and others in
slot phenoData. These two tables are combined into one
colData entry in the output object.
Each data matrix in assayData from GeoMx is stored into the
corresponding assays entry in the output object.
See also
Other jamses SE utilities:
make_se_test(),
se_collapse_by_column(),
se_collapse_by_row(),
se_detected_rows(),
se_normalize(),
se_rbind(),
se_to_assay_data(),
se_to_assay_names(),
se_to_rowcoldata(),
simulate_se_test()