Merge stats data.frame from two sestats results
Source:R/jam_sestats_merge_all_test.R
merge_statdf_all_test.RdMerge stats data.frame from two sestats results, specifically when one object has "all rows" and is intended only to produce the non-P-value statistics such as group mean, max group mean (mgm), fold, and logFC.
Arguments
- sestats_all
listwith sestats data fromse_contrast_stats()which used "all rows" of the source data, along withdefine_hits=FALSE.- sestats_test
listwith sestats data fromse_contrast_stats()which used a subset of rows, usually "detected rows" for the statistical test.- exclude_from_all
characterpattern used withjamba::unvigrep()to exclude colnames fromsestats_all. Default'P.val|^hit 'excludes P-values and hit columns.- ...
additional arguments are ignored.
Value
list object in the same format as sestats_test, with only
the elements 'stats_df' and 'stats_dfs' replaced with the expanded
complete set of data.
Details
sestats_allshould have all rows, not just those tested. It will specifically exclude stats columns with'P.val'or'^hit 'in the name, using argumentexclude_from_all.sestats_testshould have only the subset of rows tested.
This function may be used internally within jamses to automate the job of testing a subset of rows, but reporting summary values for all rows - including those rows not formally tested.
See also
Other jamses utilities:
choose_annotation_colnames(),
combine_sestats(),
contrast2comp_dev(),
fold_to_log2fold(),
intercalate(),
list2im_opt(),
list2im_value_internal(),
list_to_sestats(),
log2fold_to_fold(),
make_block_arrow_polygon(),
mark_stat_hits(),
matrix_normalize(),
point_handedness(),
point_slope_intercept(),
shortest_unique_abbreviation(),
shrinkDataFrame(),
shrink_df(),
shrink_matrix(),
sort_samples(),
strsplitOrdered(),
sub_split_vector(),
update_function_params(),
update_list_elements()